SimpleSelfRebuff:_rev("$Revision: 45542 $")

-------------------------------------------------------------------------------
-- Externals
-------------------------------------------------------------------------------

local SimpleSelfRebuff = SimpleSelfRebuff

local L = AceLibrary("AceLocale-2.2"):new("SimpleSelfRebuff")
local Tablet

local colorize = SimpleSelfRebuff.colorize
local formatDuration = SimpleSelfRebuff.formatDuration

local STATE_BUFFED  = SimpleSelfRebuff.STATE_BUFFED
local STATE_FADING  = SimpleSelfRebuff.STATE_FADING
local STATE_MISSING = SimpleSelfRebuff.STATE_MISSING

-------------------------------------------------------------------------------
-- Helpers
-------------------------------------------------------------------------------

local function GetBuffInfo(category, state, expected, actual, timeLeft)
	if state < STATE_BUFFED then
		return
	elseif state == STATE_MISSING then
		return expected.name, L["Missing"], 1, 0, 0
	else
		timeLeft = formatDuration(timeLeft, "-")
		if expected == actual then
			return actual.name, timeLeft, 0, 1, 0
		else
			return actual.name, timeLeft, 1, 1, 0
		end
	end
end

-------------------------------------------------------------------------------
-- Module declaration
-------------------------------------------------------------------------------

local FuBarPlugin = SimpleSelfRebuff:NewModule("FuBarPlugin", "FuBarPlugin-2.0")

FuBarPlugin.title = SimpleSelfRebuff.name

FuBarPlugin.OnMenuRequest = SimpleSelfRebuff.options
FuBarPlugin.options = AceLibrary("FuBarPlugin-2.0"):GetAceOptionsDataTable(FuBarPlugin)
FuBarPlugin.optionName = L["FuBar settings"]
FuBarPlugin.optionOrder = -4
 
function FuBarPlugin:OnModuleInitialize()
	self.version = SimpleSelfRebuff.version
	self.revision = SimpleSelfRebuff.revision		
end

function FuBarPlugin:OnModuleEnable()
	self:RegisterBucketEvent('SimpleSelfRebuff_UpdateDisplay', 0.1, 'UpdateDisplay')
end

function FuBarPlugin:OnTextUpdate()
	local active = self.core:IsMonitoringActive()
	if active then
		local pendingBuff = self.core:GetPendingBuff()
		if pendingBuff then
			local	name, timeLeft, r, g, b = GetBuffInfo(pendingBuff.category, pendingBuff.category:GetState())
			self:SetText(colorize(timeLeft, r, g, b))
			self:ScheduleEvent('SimpleSelfRebuff_UpdateDisplay', 1)
		else
			self:SetText('SSR')
		end
	else
		self:SetText('|cff777777SSR|r')
	end
end

function FuBarPlugin:OnTooltipUpdate()
	if not Tablet then
		Tablet = AceLibrary('Tablet-2.0')
	end
	
	local active = self.core:IsMonitoringActive()
	local cat
	
	Tablet:SetTitle(self.core.name)
	
	if not active then
		cat = Tablet:AddCategory()
		cat:AddLine('text', L["Currently inactive (resting/dead)."])
		
	else
		cat = Tablet:AddCategory("columns", 3)
		for category, state, expected, actual, timeLeft in self.core:IterateCategories(STATE_BUFFED) do
			local name, timeLeft, r, g, b = GetBuffInfo(category, state, expected, actual, timeLeft)
			if name then
				cat:AddLine(
					'text',  category.name,
					'text2', name,     'text2R', r, 'text2G', g, 'text2B', b,
					'text3', timeLeft, 'text3R', r, 'text3G', g, 'text3B', b
				)
			end
		end
		self:ScheduleEvent('SimpleSelfRebuff_UpdateDisplay', 1)		
		Tablet:SetHint(L["Green means \"ok\", yellow means \"override wanted buff\", red means \"missing\"."])
	end
	
end
